# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: epl/protobuf/query.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='epl/protobuf/query.proto',
  package='epl.protobuf',
  syntax='proto3',
  serialized_options=_b('\n\020com.epl.protobufB\nQueryProtoP\001Z+github.com/geo-grpc/api/golang/epl/protobuf\242\002\003QPB'),
  serialized_pb=_b('\n\x18\x65pl/protobuf/query.proto\x12\x0c\x65pl.protobuf\x1a\x1fgoogle/protobuf/timestamp.proto\"\x84\x01\n\x0bStringField\x12\r\n\x05value\x18\x01 \x01(\t\x12\x31\n\x08rel_type\x18\x02 \x01(\x0e\x32\x1f.epl.protobuf.FieldRelationship\x12\x33\n\x0esort_direction\x18\x04 \x01(\x0e\x32\x1b.epl.protobuf.SortDirection\"\xb3\x01\n\nFloatField\x12\r\n\x05value\x18\x01 \x01(\x02\x12\x31\n\x08rel_type\x18\x02 \x01(\x0e\x32\x1f.epl.protobuf.FieldRelationship\x12\x16\n\x0e\x62\x65tween_value1\x18\x03 \x01(\x02\x12\x16\n\x0e\x62\x65tween_value2\x18\x04 \x01(\x02\x12\x33\n\x0esort_direction\x18\x05 \x01(\x0e\x32\x1b.epl.protobuf.SortDirection\"\xb4\x01\n\x0b\x44oubleField\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x31\n\x08rel_type\x18\x02 \x01(\x0e\x32\x1f.epl.protobuf.FieldRelationship\x12\x16\n\x0e\x62\x65tween_value1\x18\x03 \x01(\x01\x12\x16\n\x0e\x62\x65tween_value2\x18\x04 \x01(\x01\x12\x33\n\x0esort_direction\x18\x05 \x01(\x0e\x32\x1b.epl.protobuf.SortDirection\"\x8b\x02\n\x0eTimestampField\x12)\n\x05value\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x08rel_type\x18\x02 \x01(\x0e\x32\x1f.epl.protobuf.FieldRelationship\x12\x32\n\x0e\x62\x65tween_value1\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0e\x62\x65tween_value2\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0esort_direction\x18\x05 \x01(\x0e\x32\x1b.epl.protobuf.SortDirection\"\xb4\x01\n\x0bUInt32Field\x12\r\n\x05value\x18\x01 \x01(\r\x12\x31\n\x08rel_type\x18\x02 \x01(\x0e\x32\x1f.epl.protobuf.FieldRelationship\x12\x16\n\x0e\x62\x65tween_value1\x18\x03 \x01(\r\x12\x16\n\x0e\x62\x65tween_value2\x18\x04 \x01(\r\x12\x33\n\x0esort_direction\x18\x05 \x01(\x0e\x32\x1b.epl.protobuf.SortDirection*2\n\rSortDirection\x12\x0e\n\nNOT_SORTED\x10\x00\x12\x08\n\x04\x44\x45SC\x10\x01\x12\x07\n\x03\x41SC\x10\x02*\x84\x01\n\x11\x46ieldRelationship\x12\x06\n\x02\x45Q\x10\x00\x12\x0c\n\x08LT_OR_EQ\x10\x02\x12\x0c\n\x08GT_OR_EQ\x10\x04\x12\x06\n\x02LT\x10\x08\x12\x06\n\x02GT\x10\x10\x12\x0b\n\x07\x42\x45TWEEN\x10 \x12\x0f\n\x0bNOT_BETWEEN\x10@\x12\x0b\n\x06NOT_EQ\x10\x80\x01\x12\x10\n\x0bSTARTS_WITH\x10\x80\x02\x42S\n\x10\x63om.epl.protobufB\nQueryProtoP\x01Z+github.com/geo-grpc/api/golang/epl/protobuf\xa2\x02\x03QPBb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_SORTDIRECTION = _descriptor.EnumDescriptor(
  name='SortDirection',
  full_name='epl.protobuf.SortDirection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_SORTED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESC', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ASC', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1028,
  serialized_end=1078,
)
_sym_db.RegisterEnumDescriptor(_SORTDIRECTION)

SortDirection = enum_type_wrapper.EnumTypeWrapper(_SORTDIRECTION)
_FIELDRELATIONSHIP = _descriptor.EnumDescriptor(
  name='FieldRelationship',
  full_name='epl.protobuf.FieldRelationship',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EQ', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LT_OR_EQ', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GT_OR_EQ', index=2, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LT', index=3, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GT', index=4, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BETWEEN', index=5, number=32,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_BETWEEN', index=6, number=64,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_EQ', index=7, number=128,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STARTS_WITH', index=8, number=256,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1081,
  serialized_end=1213,
)
_sym_db.RegisterEnumDescriptor(_FIELDRELATIONSHIP)

FieldRelationship = enum_type_wrapper.EnumTypeWrapper(_FIELDRELATIONSHIP)
NOT_SORTED = 0
DESC = 1
ASC = 2
EQ = 0
LT_OR_EQ = 2
GT_OR_EQ = 4
LT = 8
GT = 16
BETWEEN = 32
NOT_BETWEEN = 64
NOT_EQ = 128
STARTS_WITH = 256



_STRINGFIELD = _descriptor.Descriptor(
  name='StringField',
  full_name='epl.protobuf.StringField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='epl.protobuf.StringField.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rel_type', full_name='epl.protobuf.StringField.rel_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_direction', full_name='epl.protobuf.StringField.sort_direction', index=2,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=208,
)


_FLOATFIELD = _descriptor.Descriptor(
  name='FloatField',
  full_name='epl.protobuf.FloatField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='epl.protobuf.FloatField.value', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rel_type', full_name='epl.protobuf.FloatField.rel_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='between_value1', full_name='epl.protobuf.FloatField.between_value1', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='between_value2', full_name='epl.protobuf.FloatField.between_value2', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_direction', full_name='epl.protobuf.FloatField.sort_direction', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=390,
)


_DOUBLEFIELD = _descriptor.Descriptor(
  name='DoubleField',
  full_name='epl.protobuf.DoubleField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='epl.protobuf.DoubleField.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rel_type', full_name='epl.protobuf.DoubleField.rel_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='between_value1', full_name='epl.protobuf.DoubleField.between_value1', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='between_value2', full_name='epl.protobuf.DoubleField.between_value2', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_direction', full_name='epl.protobuf.DoubleField.sort_direction', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=573,
)


_TIMESTAMPFIELD = _descriptor.Descriptor(
  name='TimestampField',
  full_name='epl.protobuf.TimestampField',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='epl.protobuf.TimestampField.value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rel_type', full_name='epl.protobuf.TimestampField.rel_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='between_value1', full_name='epl.protobuf.TimestampField.between_value1', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='between_value2', full_name='epl.protobuf.TimestampField.between_value2', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_direction', full_name='epl.protobuf.TimestampField.sort_direction', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=576,
  serialized_end=843,
)


_UINT32FIELD = _descriptor.Descriptor(
  name='UInt32Field',
  full_name='epl.protobuf.UInt32Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='epl.protobuf.UInt32Field.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rel_type', full_name='epl.protobuf.UInt32Field.rel_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='between_value1', full_name='epl.protobuf.UInt32Field.between_value1', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='between_value2', full_name='epl.protobuf.UInt32Field.between_value2', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sort_direction', full_name='epl.protobuf.UInt32Field.sort_direction', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=846,
  serialized_end=1026,
)

_STRINGFIELD.fields_by_name['rel_type'].enum_type = _FIELDRELATIONSHIP
_STRINGFIELD.fields_by_name['sort_direction'].enum_type = _SORTDIRECTION
_FLOATFIELD.fields_by_name['rel_type'].enum_type = _FIELDRELATIONSHIP
_FLOATFIELD.fields_by_name['sort_direction'].enum_type = _SORTDIRECTION
_DOUBLEFIELD.fields_by_name['rel_type'].enum_type = _FIELDRELATIONSHIP
_DOUBLEFIELD.fields_by_name['sort_direction'].enum_type = _SORTDIRECTION
_TIMESTAMPFIELD.fields_by_name['value'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMESTAMPFIELD.fields_by_name['rel_type'].enum_type = _FIELDRELATIONSHIP
_TIMESTAMPFIELD.fields_by_name['between_value1'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMESTAMPFIELD.fields_by_name['between_value2'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMESTAMPFIELD.fields_by_name['sort_direction'].enum_type = _SORTDIRECTION
_UINT32FIELD.fields_by_name['rel_type'].enum_type = _FIELDRELATIONSHIP
_UINT32FIELD.fields_by_name['sort_direction'].enum_type = _SORTDIRECTION
DESCRIPTOR.message_types_by_name['StringField'] = _STRINGFIELD
DESCRIPTOR.message_types_by_name['FloatField'] = _FLOATFIELD
DESCRIPTOR.message_types_by_name['DoubleField'] = _DOUBLEFIELD
DESCRIPTOR.message_types_by_name['TimestampField'] = _TIMESTAMPFIELD
DESCRIPTOR.message_types_by_name['UInt32Field'] = _UINT32FIELD
DESCRIPTOR.enum_types_by_name['SortDirection'] = _SORTDIRECTION
DESCRIPTOR.enum_types_by_name['FieldRelationship'] = _FIELDRELATIONSHIP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StringField = _reflection.GeneratedProtocolMessageType('StringField', (_message.Message,), dict(
  DESCRIPTOR = _STRINGFIELD,
  __module__ = 'epl.protobuf.query_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.StringField)
  ))
_sym_db.RegisterMessage(StringField)

FloatField = _reflection.GeneratedProtocolMessageType('FloatField', (_message.Message,), dict(
  DESCRIPTOR = _FLOATFIELD,
  __module__ = 'epl.protobuf.query_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.FloatField)
  ))
_sym_db.RegisterMessage(FloatField)

DoubleField = _reflection.GeneratedProtocolMessageType('DoubleField', (_message.Message,), dict(
  DESCRIPTOR = _DOUBLEFIELD,
  __module__ = 'epl.protobuf.query_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.DoubleField)
  ))
_sym_db.RegisterMessage(DoubleField)

TimestampField = _reflection.GeneratedProtocolMessageType('TimestampField', (_message.Message,), dict(
  DESCRIPTOR = _TIMESTAMPFIELD,
  __module__ = 'epl.protobuf.query_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.TimestampField)
  ))
_sym_db.RegisterMessage(TimestampField)

UInt32Field = _reflection.GeneratedProtocolMessageType('UInt32Field', (_message.Message,), dict(
  DESCRIPTOR = _UINT32FIELD,
  __module__ = 'epl.protobuf.query_pb2'
  # @@protoc_insertion_point(class_scope:epl.protobuf.UInt32Field)
  ))
_sym_db.RegisterMessage(UInt32Field)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
